@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:      4/ 4/2002
-// RCS-ID:      $Id: xr_constants.cpp,v 1.4 2003/05/05 20:38:42 mbarbon Exp $
+// RCS-ID:      $Id: xr_constants.cpp,v 1.5 2003/07/25 20:36:15 mbarbon Exp $
 // Copyright:   (c) 2002-2003 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -30,6 +30,20 @@ double xrc_constant( const char* name, int arg )
     case 'X':
         r( wxXRC_USE_LOCALE );
         r( wxXRC_NO_SUBCLASSING );
+
+        r( wxXML_ELEMENT_NODE );
+        r( wxXML_ATTRIBUTE_NODE );
+        r( wxXML_TEXT_NODE );
+        r( wxXML_CDATA_SECTION_NODE );
+        r( wxXML_ENTITY_REF_NODE );
+        r( wxXML_ENTITY_NODE );
+        r( wxXML_PI_NODE );
+        r( wxXML_COMMENT_NODE );
+        r( wxXML_DOCUMENT_NODE );
+        r( wxXML_DOCUMENT_TYPE_NODE );
+        r( wxXML_DOCUMENT_FRAG_NODE );
+        r( wxXML_NOTATION_NODE );
+        r( wxXML_HTML_DOCUMENT_NODE );
         break;
     }
 #undef r
